versy
-----

Usage
=====

.. code-block:: bash

       versy [-h] [--changelog CHANGELOG] [--dry-run] [--edit] [--file FILE] [--message MESSAGE]
             [--push] [--root ROOT] [--verbose]
             [action]

Description
===========

Automatically update the version number and change log for a Python repository

Positional arguments
====================

``action``
  Actions are: patch, minor, major, new, show, <new version number>

Optional arguments
==================

``-h``, ``--help``
  Show this help message and exit

``--changelog CHANGELOG``, ``-c CHANGELOG``
  Specify the name of a new change log

``--dry-run``, ``-d``
  Don't actually make the changes, just print the diffs

``--edit``, ``-e``
  Bring up the change log in an editor

``--file FILE``, ``-f FILE``
  Specify the file containing __version__

``--message MESSAGE``, ``-m MESSAGE``
  Set change log message

``--push``, ``-p``
  Git push after committing changes

``--root ROOT``, ``-r ROOT``
  Root directory to search for a version number

``--verbose``, ``-v``
  Print more stuff

(automatically generated by `doks <https://github.com/rec/doks/>`_ on 2020-11-07T12:35:56.188835)
